/**
  Copyright (c) 2007 Freescale Semiconductor
  
  \file       GPIO.h
  \brief      This file provides resources for GPIO interface of modules.
  \author     Freescale Semiconductor
  \author     RF, Analog & Sensor Group
  \author     Eduardo Muriel
  \version    1.3
  \date       18/10/2007
  
  * History:  23/10/2007 - Public and private separations added
              18/10/2007 - File was created.

* Copyright (c) 2007, Freescale, Inc.  All rights reserved.
*
*
* No part of this document must be reproduced in any form - including copied,
* transcribed, printed or by any electronic means - without specific written
* permission from Freescale Semiconductor.
*
  
*/

#include "derivative.h"
#include "Common.h"

#ifndef _GPIO_H_
#define _GPIO_H_

typedef struct {               /** Structure for the virtual GPIO ports*/
  UINT8*  PinPort;
  UINT8  PinMask;
} VIRTUAL_PORT;

/*******    Public    *****************/
#pragma CONST_SEG CONST_ROM
const extern VIRTUAL_PORT vpPort1[];       /** Virtual GPIO Port declaration */
const extern VIRTUAL_PORT vpPort2[];       /** Virtual GPIO Port declaration */
#pragma CONST_SEG DEFAULT

#define PIN_OUTPUT(x,y) *(UINT8 *)(x+DD_OFFSET) |= y  /** vGPIO pin as output   */
#define PIN_INPUT(x,y)  *(UINT8 *)(x+DD_OFFSET) &= ~y /** vGPIO pin as input    */
#define PIN_CLEAR(x,y)                       *x &= ~y /** vGPIO pin output 0    */
#define PIN_SET(x,y)                         *x |= y  /** vGPIO pin output 1    */
#define PIN_TOGGLE(x,y)                      *x ^= y  /** vGPIO pin complement  */

#define v1GPIO_PORT(x)  vpPort1[x].PinPort
#define v1GPIO_PIN(x)   vpPort1[x].PinMask

#define v2GPIO_PORT(x)  vpPort2[x].PinPort
#define v2GPIO_PIN(x)   vpPort2[x].PinMask

/**************************************/

/*******    Private   *****************/
/** Macro for virtual port pin creation */
#define GPIO_PIN(x,y)     &PT##x##D,PT##x##D_PT##x##D##y##_MASK

#ifdef _MC9S08RG60_H
    #define DD_OFFSET   2   /** Offset from data to data direction register */
#else
    #define DD_OFFSET   1   /** Offset from data to data direction register */
#endif
/**************************************/

#endif /** _GPIO_H_ */