/**
  Copyright (c) 2007 Freescale Semiconductor
  
  \file     Services.c
  \brief    This module contains MCU initializations, part of services layer.
  \author   Freescale Semiconductor
  \author   RF, Analog & Sensor Group
  \author   Eduardo Muriel
  \version  1.2
  \date     23/10/2007
  
* Copyright (c) 2007, Freescale, Inc.  All rights reserved.
*
*
* No part of this document must be reproduced in any form - including copied,
* transcribed, printed or by any electronic means - without specific written
* permission from Freescale Semiconductor.
*

*/
#include "Common.h"
#include "Services.h"
#include "Timer.h"
#include "GPIO.h"
#include "derivative.h" 

static UINT8 Clocks_Init(void);

/**
 * \brief   Function to perform all MCU initialization that falls in services layer
 * \author  Eduardo Muriel
 * \param   None
 * \return  8 bits status code
*/
UINT8 MCU_Init(void)
{
    UINT8 u8Status;

    SOPT_COPE = 0;

    u8Status = Clocks_Init();

    TIMER_CONFIGURE();        /** Timer initialization */

    //__asm MOV #%HIGH_6_13(vpPort1),PAGESEL
    PAGESEL = 0xE0;
     
    return u8Status;
}

/**
 * \brief   Function to initialize CPU clocks
 * \author  Eduardo Muriel
 * \param   None
 * \return  8 bits status code
*/
UINT8 Clocks_Init(void)
{
    #ifdef ICSC1
        UINT8 i;
        
        PAGESEL = (TRIM_ADD>>6);
        
        if (TRIM_VAL != 0xFF)
        {
            ICSTRM = TRIM_VAL;		    /** load trim value if location not blank */
        }
        
        ICSC1 = ICSC1_INIT;
        for (i=0x10;i>0;i--)
        {
            __RESET_WATCHDOG();
        }
        
        ICSC2 = ICSC2_INIT;														
        while (ICSC1_CLKS != ICSSC_CLKST);
    
    #elif defined(ICGC1)
        
        PAGESEL = (TRIM_ADD>>6);
        
        if (TRIM_VAL != 0xFF)
        {
            ICGTRM = TRIM_VAL;		    /** load trim value if location not blank */
        }
        
        ICGC1 = ICGC1_INIT;
        
        ICGC2 = ICGC2_INIT;
        
        while(!(ICGS1 & ICG_LOCKED));
    #endif

    return STAT_OK; 
}