/**
  Copyright (c) 2007 Freescale Semiconductor
  
  \file       Timer.h
  \brief      Macros, configuration constants and timer registers
  \brief      defined in this file.
  \author     Freescale Semiconductor
  \author     Sensors and Actuator Solutions Division
  \author     Eduardo Muriel
  \version    1.0
  \date       18/10/2007
  
* Copyright (c) 2007, Freescale, Inc.  All rights reserved.
*
*
* No part of this document must be reproduced in any form - including copied,
* transcribed, printed or by any electronic means - without specific written
* permission from Freescale Semiconductor.
*  
  
*/

#include "derivative.h"
#include "SL_HAL_Int.h"

#ifndef _TIMER_H_
#define _TIMER_H_

/*******    Public    *****************/
#define fTimeout             TIMER_TOF

/** Timer public macros */
#define TIMER_CONFIGURE()    TIMER_CLKS = TIMER_PRESCALE | (CLOCK_SOURCE << 4); \
                             TIMER_SC   = TIMER_IE   /** Configure timer module */
#define TIMER_SET_CLK(y)     MTIMCLK &= 0xF0; \
                             MTIMCLK |= (y & 0x0F)
#define TIMER_SET_MOD(x)     TIMER_MOD  = x;                        /** Set modulo value       */
#define TIMER_START()        TIMER_SC  &= TIMER_ON                  /** Start Timer            */
#define TIMER_STOP()         TIMER_SC  |= TIMER_OFF                 /** Stop Timer             */
#define TIMER_RESET()        TIMER_SC  |= TIMER_RST                 /** Reset counter          */ 
#define TIMER_GET_COUNT()    TIMER_CNT                             /** Read counter value     */
/**************************************/

/*******    Private   *****************/
/** MTIM Module selection for RS08 MCUs */
#ifdef MTIMSC
  #define TIMER_ADDRESS	  &MTIMSC     
#else
  #define TIMER_ADDRESS	  &MTIM1SC     
  #define MTIMSCSTR        TPM1SCSTR
#endif

/** Clocks configuration*/
#define CLOCK_SOURCE	0		  /** Use to set clock source for timer	*/
								    /** 0 = Bus clock                       */
									/** 1 = XCLK - not all MCUs have XCLK   */							
									/** 2 = Ext clock                       */
									/** 3 = Ext clock                       */

#define TIMER_CLK     2000		  /** Set timer clock FREQUENCY in kHz	  */

#if (BUS_CLK/TIMER_CLK) <= 1
  #define TIMER_PRESCALE	0	  /** Specify timer prescaler value		  */
#elif (BUS_CLK/TIMER_CLK) < 3
  #define TIMER_PRESCALE	1	  /** Specify timer prescaler value		  */
#elif (BUS_CLK/TIMER_CLK) < 7
  #define TIMER_PRESCALE	2	  /** Specify timer prescaler value		  */
#elif (BUS_CLK/TIMER_CLK) < 15
  #define TIMER_PRESCALE	3	  /** Specify timer prescaler value		  */
#else (BUS_CLK/TIMER_CLK) < 15
  #define TIMER_PRESCALE	4	  /** Specify timer prescaler value		  */
#endif

/** Interrupt configuration */
#define TIMER_IE   0x40		      /** Set timer interrupt enable bit 	  */
												                  
/** Timer register offsets */
/** Register address offsets for normal S08 timer */
#define TIMER_SC    *(volatile UINT8 *)(TIMER_ADDRESS+0) /** Timer status/ctrl      */
#define TIMER_TOF  (*(volatile MTIMSCSTR *)(TIMER_ADDRESS+0)).Bits.TOF /** Timer overflow flag		*/
#define TIMER_CLKS  *(volatile UINT8 *)(TIMER_ADDRESS+1) /** Timer status/ctrl      */
#define TIMER_CNT	*(volatile UINT8 *)(TIMER_ADDRESS+2) /** Timer counter          */
#define TIMER_MOD	*(volatile UINT8 *)(TIMER_ADDRESS+3) /** Timer modulus          */

/** Timer control reg masks */
#define TIMER_ON	        0xEF    /** Value to OR to SC register to start timer   */
#define TIMER_OFF	        0x10    /** Value to AND to SC register to stop timer   */
#define TIMER_RST           0x20    /** Value to OR to SC register to reset timer   */
/**************************************/

#endif /** _TIMER_H_ */