/**
  Copyright (c) 2007 Freescale Semiconductor
  
  \file       Proximity.h
  \brief      Contains all necesary macros and definitions for proximity module
  \author     Freescale Semiconductor
  \author     RF, Analog & Sensor Group
  \author     Eduardo Muriel, Ulises Corrales
  \version    1.3
  \date       8/10/2007
  
  * History:  23/10/2007 - Private and public separation added.
              18/10/2007 - Original contents segmentated in different files
              10/10/2007 - Electrode list and macros created to improve flexibility.
               5/10/2007 - File was created.
               
* Copyright (c) 2007, Freescale, Inc.  All rights reserved.
*
*
* No part of this document must be reproduced in any form - including copied,
* transcribed, printed or by any electronic means - without specific written
* permission from Freescale Semiconductor.
*
               
*/

#include "Timer.h"
#include "GPIO.h"

#ifndef _PROXIMITY_H
#define _PROXIMITY_H

/*******    Public    *****************/
/** Data type definitions */
typedef UINT8 ELEC_STAT_REG;

/** Proximity interface   */
UINT8 UpdateElectrodeStatus(UINT8 u8Electrode);
UINT8 ProximityInit(void);

#define N_ELECTRODES          8                /** Number of electrodes in application */
#define ELECTRODE_ALL         0x80             /** Command for sampling all electrodes */

extern UINT8 gau8ElectrodeAvg[N_ELECTRODES];   /** Table of average values             */
extern ELEC_STAT_REG gesElectrodeStatus;       /** Electrodes touch status register    */

enum                                           /** Electrode symbol list               */
{
    E1 = 0,
    E2,
    E3,
    E4,
    E5,
    E6,
    E7,
    E8
};

/**************************************/
                               
/*******    Private   *****************/
/** Sampling parameters */
#define TIME_LIMIT            250                 /** Counter timeout value         */

/** Electrode related macro definitions*/
#define ELEC_PORT(x)          vpPort1[x].PinPort  /** Virtual port pointer element  */
#define ELEC_PIN(x)           vpPort1[x].PinMask  /** Virtual port pin mask         */

#define ELECTRODE_READ(x,y)         PIN_INPUT(x,y);  /** Set electrode pin as input */
#define ELECTRODE_TEST(x,y)         (*x & y)         /** Check logic status         */
#define ELECTRODE_DISCHARGE(x,y)    PIN_OUTPUT(x,y); \
                                    PIN_CLEAR(x,y)   /** Sequence for discharge     */

/** Counter macros */
#define COUNTER_START()       TIMER_SET_MOD(TIME_LIMIT); \
                              TIMER_START()          /** Start Measurement Timer    */
#define COUNTER_STOP()        TIMER_STOP()
#define COUNTER_RESET()       TIMER_RESET()
#define COUNTER_VALUE         TIMER_GET_COUNT()
/**************************************/

#endif /** _PROXIMITY_H */