/**
  Copyright (c) 2007 Freescale Semiconductor
  
  \file       Timer.h
  \brief      Macros, configuration constants and timer registers
  \brief      defined in this file.
  \author     Freescale Semiconductor
  \author     RF, Analog & Sensor Group
  \author     Eduardo Muriel
  \version    1.3
  \date       18/10/2007
  \warning    The flags variable must be allocated in the direct
  \warning    data page. Pragma statements should be checked for
  \warning    compatibility.
  
  * History:  23/10/2007 - Public and private separations added
              18/10/2007 - File was created.

* Copyright (c) 2007, Freescale, Inc.  All rights reserved.
*
*
* No part of this document must be reproduced in any form - including copied,
* transcribed, printed or by any electronic means - without specific written
* permission from Freescale Semiconductor.
*
  
*/

#include "derivative.h"
#include "SL_HAL_Int.h"

#ifndef _TIMER_H_
#define _TIMER_H_

typedef union {                 /** Data type for flags register */
  byte Byte;
  struct {
    byte             :1;  
    byte             :1;  
    byte             :1;  
    byte             :1;  
    byte             :1;  
    byte             :1;  
    byte             :1;  
    byte Timeout     :1;  
  } Bits;
} FLAGS_REG;

/*******    Public    *****************/
#define fTimeout              frTimer_flags.Bits.Timeout            /** Timer timeout flag    */

/** Timer public macros */
#define TIMER_CONFIGURE()    TIMER_SC = TIMER_PRESCALE | TIMER_IE   /** Configure timer module */
#define TIMER_SET_MOD(x)     TIMER_MOD  = x;                        /** Set modulo value       */
#define TIMER_START()        TIMER_SC |= TIMER_ON                   /** Start Timer            */
#define TIMER_STOP()         TIMER_SC &= TIMER_OFF                  /** Stop Timer             */
#define TIMER_RESET()        TIMER_CNT = 0x00                       /** Reset counter          */ 
#define TIMER_GET_COUNT()    TIMER_CNTL                             /** Read counter value     */
/**************************************/

/*******    Private   *****************/
#ifndef _MCF51QE128_H
    #pragma DATA_SEG _DATA_ZEROPAGE
    extern FLAGS_REG near frTimer_flags;
    #pragma DATA_SEG DEFAULT
#else
    extern FLAGS_REG  frTimer_flags;
#endif

/** TPM Module selection for S08 MCUs */
#ifdef TPMSC
  #define TIMER_ADDRESS	  &TPMSC     
#else
  #define TIMER_ADDRESS	  &TPM1SC     
  #define TPMSCSTR        TPM1SCSTR
#endif

/** Clocks configuration*/
#define CLOCK_SOURCE	1		  /** Use to set clock source for timer	*/
								    /** 1 = Bus clock                       */
									/** 2 = XCLK - not all MCUs have XCLK   */							
									/** 3 = Ext clock                       */

#define TIMER_CLK     2000		  /** Set timer clock FREQUENCY in kHz	  */

#if (BUS_CLK/TIMER_CLK) <= 1
  #define TIMER_PRESCALE	0	  /** Specify timer prescaler value		  */
#elif (BUS_CLK/TIMER_CLK) < 3
  #define TIMER_PRESCALE	1	  /** Specify timer prescaler value		  */
#elif (BUS_CLK/TIMER_CLK) < 7
  #define TIMER_PRESCALE	2	  /** Specify timer prescaler value		  */
#elif (BUS_CLK/TIMER_CLK) < 15
  #define TIMER_PRESCALE	3	  /** Specify timer prescaler value		  */
#else (BUS_CLK/TIMER_CLK) < 15
  #define TIMER_PRESCALE	4	  /** Specify timer prescaler value		  */
#endif

/** Interrupt configuration */
#define TIMER_IE   0x40		      /** Set timer interrupt enable bit 	  */

#ifdef VectorNumber_Vtpmovf
  #define TIMER_VECTOR_NUM	  VectorNumber_Vtpmovf     
#else
  #define TIMER_VECTOR_NUM	  VectorNumber_Vtpm1ovf     
#endif
												                  
/** Timer register offsets */
/** Register address offsets for normal S08 timer */
#define TIMER_SC    *(volatile UINT8  *)(TIMER_ADDRESS+0) /** Timer status/ctrl      */
#define TIMER_TOF  (*(volatile TPMSCSTR *)(TIMER_ADDRESS+0)).Bits.TOF /** Timer overflow flag		*/
#define TIMER_CNT	*(volatile UINT16 *)(TIMER_ADDRESS+1) /** Timer counter          */
#define TIMER_CNTH	*(volatile UINT8  *)(TIMER_ADDRESS+1) /** Timer counter H		*/
#define TIMER_CNTL	*(volatile UINT8  *)(TIMER_ADDRESS+2) /** Timer counter L		*/
#define TIMER_MOD	*(volatile UINT16 *)(TIMER_ADDRESS+3) /** Timer modulus          */
#define TIMER_MODH	*(volatile UINT8  *)(TIMER_ADDRESS+3) /** Timer modulus H		*/
#define TIMER_MODL	*(volatile UINT16 *)(TIMER_ADDRESS+4) /** Timer modulus L		*/

/** Timer control reg masks */
#define TIMER_ON	        CLOCK_SOURCE<<3    /** Value to OR to SC register to start timer   */
#define TIMER_OFF	        0xE7               /** Value to AND to SC register to stop timer   */
#define TIMER_CLEAR_TOF()   TIMER_TOF = 0      /** Clear timer over flag        */
/**************************************/

#endif /** _TIMER_H_ */